@@ -15,8 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """Example DAG demonstrating the usage of the @taskgroup decorator."""
+from __future__ import annotations
 
 import pendulum
 
@@ -28,39 +28,39 @@ from airflow.models.dag import DAG
 # Creating Tasks
 @task
 def task_start():
-    """Dummy Task which is First Task of Dag"""
+    """Empty Task which is First Task of Dag"""
     return '[Task_start]'
 
 
 @task
-def task_1(value):
-    """Dummy Task1"""
+def task_1(value: int) -> str:
+    """Empty Task1"""
     return f'[ Task1 {value} ]'
 
 
 @task
-def task_2(value):
-    """Dummy Task2"""
+def task_2(value: str) -> str:
+    """Empty Task2"""
     return f'[ Task2 {value} ]'
 
 
 @task
-def task_3(value):
-    """Dummy Task3"""
+def task_3(value: str) -> None:
+    """Empty Task3"""
     print(f'[ Task3 {value} ]')
 
 
 @task
-def task_end():
-    """Dummy Task which is Last Task of Dag"""
+def task_end() -> None:
+    """Empty Task which is Last Task of Dag"""
     print('[ Task_End  ]')
 
 
 # Creating TaskGroups
 @task_group
-def task_group_function(value):
+def task_group_function(value: int) -> None:
     """TaskGroup for grouping related Tasks"""
-    return task_3(task_2(task_1(value)))
+    task_3(task_2(task_1(value)))
 
 
 # Executing Tasks and TaskGroups
