@@ -65,7 +65,6 @@ class S3CreateBucketOperator(BaseOperator):
         self.bucket_name = bucket_name
         self.region_name = region_name
         self.aws_conn_id = aws_conn_id
-        self.region_name = region_name
 
     def execute(self, context: 'Context'):
         s3_hook = S3Hook(aws_conn_id=self.aws_conn_id, region_name=self.region_name)
@@ -393,11 +392,13 @@ class S3CreateObjectOperator(BaseOperator):
     def execute(self, context: 'Context'):
         s3_hook = S3Hook(aws_conn_id=self.aws_conn_id, verify=self.verify)
 
+        s3_bucket, s3_key = s3_hook.get_s3_bucket_key(self.s3_bucket, self.s3_key, 'dest_bucket', 'dest_key')
+
         if isinstance(self.data, str):
             s3_hook.load_string(
                 self.data,
-                self.s3_key,
-                self.s3_bucket,
+                s3_key,
+                s3_bucket,
                 self.replace,
                 self.encrypt,
                 self.encoding,
@@ -405,9 +406,7 @@ class S3CreateObjectOperator(BaseOperator):
                 self.compression,
             )
         else:
-            s3_hook.load_bytes(
-                self.data, self.s3_key, self.s3_bucket, self.replace, self.encrypt, self.acl_policy
-            )
+            s3_hook.load_bytes(self.data, s3_key, s3_bucket, self.replace, self.encrypt, self.acl_policy)
 
 
 class S3DeleteObjectsOperator(BaseOperator):
@@ -618,6 +617,10 @@ class S3ListOperator(BaseOperator):
     This operator returns a python list with the name of objects which can be
     used by `xcom` in the downstream task.
 
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:S3ListOperator`
+
     :param bucket: The S3 bucket where to find the objects. (templated)
     :param prefix: Prefix string to filters the objects whose name begin with
         such prefix. (templated)
@@ -689,6 +692,10 @@ class S3ListPrefixesOperator(BaseOperator):
     This operator returns a python list with the name of all subfolders which
     can be used by `xcom` in the downstream task.
 
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:S3ListPrefixesOperator`
+
     :param bucket: The S3 bucket where to find the subfolders. (templated)
     :param prefix: Prefix string to filter the subfolders whose name begin with
         such prefix. (templated)
