@@ -20,12 +20,13 @@
 
 import csv
 import json
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Optional, Sequence, Tuple, Union
+from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Optional, Sequence, Tuple, Union, cast
 
 from databricks.sql.utils import ParamEscaper
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
+from airflow.providers.common.sql.hooks.sql import fetch_all_handler
 from airflow.providers.databricks.hooks.databricks_sql import DatabricksSqlHook
 
 if TYPE_CHECKING:
@@ -41,7 +42,7 @@ class DatabricksSqlOperator(BaseOperator):
         :ref:`howto/operator:DatabricksSqlOperator`
 
     :param databricks_conn_id: Reference to
-        :ref:`Databricks connection id<howto/connection:databricks>`
+        :ref:`Databricks connection id<howto/connection:databricks>` (templated)
     :param http_path: Optional string specifying HTTP path of Databricks SQL Endpoint or cluster.
         If not specified, it should be either specified in the Databricks connection's extra parameters,
         or ``sql_endpoint_name`` must be specified.
@@ -62,20 +63,28 @@ class DatabricksSqlOperator(BaseOperator):
     :param output_format: format of output data if ``output_path` is specified.
         Possible values are ``csv``, ``json``, ``jsonl``. Default is ``csv``.
     :param csv_params: parameters that will be passed to the ``csv.DictWriter`` class used to write CSV data.
+    :param do_xcom_push: If True, then the result of SQL executed will be pushed to an XCom.
     """
 
-    template_fields: Sequence[str] = ('sql', '_output_path', 'schema', 'catalog', 'http_headers')
+    template_fields: Sequence[str] = (
+        'sql',
+        '_output_path',
+        'schema',
+        'catalog',
+        'http_headers',
+        'databricks_conn_id',
+    )
     template_ext: Sequence[str] = ('.sql',)
     template_fields_renderers = {'sql': 'sql'}
 
     def __init__(
         self,
         *,
-        sql: Union[str, List[str]],
+        sql: Union[str, Iterable[str]],
         databricks_conn_id: str = DatabricksSqlHook.default_conn_name,
         http_path: Optional[str] = None,
         sql_endpoint_name: Optional[str] = None,
-        parameters: Optional[Union[Mapping, Iterable]] = None,
+        parameters: Optional[Union[Iterable, Mapping]] = None,
         session_configuration=None,
         http_headers: Optional[List[Tuple[str, str]]] = None,
         catalog: Optional[str] = None,
@@ -113,6 +122,7 @@ class DatabricksSqlOperator(BaseOperator):
             http_headers=self.http_headers,
             catalog=self.catalog,
             schema=self.schema,
+            caller="DatabricksSqlOperator",
             **self.client_parameters,
         )
 
@@ -147,10 +157,11 @@ class DatabricksSqlOperator(BaseOperator):
         else:
             raise AirflowException(f"Unsupported output format: '{self._output_format}'")
 
-    def execute(self, context: 'Context') -> Any:
+    def execute(self, context: 'Context'):
         self.log.info('Executing: %s', self.sql)
         hook = self._get_hook()
-        schema, results = hook.run(self.sql, parameters=self.parameters)
+        response = hook.run(self.sql, parameters=self.parameters, handler=fetch_all_handler)
+        schema, results = cast(List[Tuple[Any, Any]], response)[0]
         # self.log.info('Schema: %s', schema)
         # self.log.info('Results: %s', results)
         self._format_output(schema, results)
@@ -176,7 +187,7 @@ class DatabricksCopyIntoOperator(BaseOperator):
     :param file_format: Required file format. Supported formats are
         ``CSV``, ``JSON``, ``AVRO``, ``ORC``, ``PARQUET``, ``TEXT``, ``BINARYFILE``.
     :param databricks_conn_id: Reference to
-        :ref:`Databricks connection id<howto/connection:databricks>`
+        :ref:`Databricks connection id<howto/connection:databricks>` (templated)
     :param http_path: Optional string specifying HTTP path of Databricks SQL Endpoint or cluster.
         If not specified, it should be either specified in the Databricks connection's extra parameters,
         or ``sql_endpoint_name`` must be specified.
@@ -207,6 +218,7 @@ class DatabricksCopyIntoOperator(BaseOperator):
         '_file_location',
         '_files',
         '_table_name',
+        'databricks_conn_id',
     )
 
     def __init__(
@@ -277,6 +289,7 @@ class DatabricksCopyIntoOperator(BaseOperator):
             http_headers=self._http_headers,
             catalog=self._catalog,
             schema=self._schema,
+            caller="DatabricksCopyIntoOperator",
             **self._client_parameters,
         )
 
