@@ -21,8 +21,10 @@ Example Airflow DAG that uses Google AutoML services.
 """
 import os
 from datetime import datetime
+from typing import cast
 
 from airflow import models
+from airflow.models.xcom_arg import XComArg
 from airflow.providers.google.cloud.hooks.automl import CloudAutoMLHook
 from airflow.providers.google.cloud.operators.automl import (
     AutoMLCreateDatasetOperator,
@@ -59,7 +61,6 @@ extract_object_id = CloudAutoMLHook.extract_object_id
 # Example DAG for AutoML Natural Language Text Classification
 with models.DAG(
     "example_automl_text_cls",
-    schedule_interval=None,  # Override to match your needs
     start_date=datetime(2021, 1, 1),
     catchup=False,
     tags=['example'],
@@ -68,7 +69,7 @@ with models.DAG(
         task_id="create_dataset_task", dataset=DATASET, location=GCP_AUTOML_LOCATION
     )
 
-    dataset_id = create_dataset_task.output['dataset_id']
+    dataset_id = cast(str, XComArg(create_dataset_task, key='dataset_id'))
 
     import_dataset_task = AutoMLImportDataOperator(
         task_id="import_dataset_task",
@@ -81,7 +82,7 @@ with models.DAG(
 
     create_model = AutoMLTrainModelOperator(task_id="create_model", model=MODEL, location=GCP_AUTOML_LOCATION)
 
-    model_id = create_model.output['model_id']
+    model_id = cast(str, XComArg(create_model, key='model_id'))
 
     delete_model_task = AutoMLDeleteModelOperator(
         task_id="delete_model_task",
