@@ -56,7 +56,6 @@ def process_line_and_extract_dataflow_job_id_callback(
     :py:class:`~airflow.providers.apache.beam.hooks.beam.BeamCommandRunner`
 
     :param on_new_job_id_callback: Callback called when the job ID is known
-    :type on_new_job_id_callback: callback
     """
 
     def _process_line_and_extract_job_id(
@@ -212,7 +211,6 @@ class _DataflowJobsController(LoggingMixin):
         self._jobs: Optional[List[dict]] = None
         self.drain_pipeline = drain_pipeline
         self._wait_until_finished = wait_until_finished
-        self._jobs: Optional[List[dict]] = None
 
     def is_job_running(self) -> bool:
         """
@@ -252,7 +250,6 @@ class _DataflowJobsController(LoggingMixin):
         Helper method to fetch the job with the specified Job ID.
 
         :param job_id: Job ID to get.
-        :type job_id: str
         :return: the Job
         :rtype: dict
         """
@@ -273,7 +270,6 @@ class _DataflowJobsController(LoggingMixin):
         Helper method to fetch the job metrics with the specified Job ID.
 
         :param job_id: Job ID to get.
-        :type job_id: str
         :return: the JobMetrics. See:
             https://cloud.google.com/dataflow/docs/reference/rest/v1b3/JobMetrics
         :rtype: dict
@@ -294,7 +290,6 @@ class _DataflowJobsController(LoggingMixin):
         Helper method to fetch ListJobMessagesResponse with the specified Job ID.
 
         :param job_id: Job ID to get.
-        :type job_id: str
         :return: yields the ListJobMessagesResponse. See:
             https://cloud.google.com/dataflow/docs/reference/rest/v1b3/ListJobMessagesResponse
         :rtype: Generator[dict, None, None]
@@ -324,7 +319,6 @@ class _DataflowJobsController(LoggingMixin):
         Helper method to fetch the job messages with the specified Job ID.
 
         :param job_id: Job ID to get.
-        :type job_id: str
         :return: the list of JobMessages. See:
             https://cloud.google.com/dataflow/docs/reference/rest/v1b3/ListJobMessagesResponse#JobMessage
         :rtype: List[dict]
@@ -339,7 +333,6 @@ class _DataflowJobsController(LoggingMixin):
         Helper method to fetch the job autoscaling events with the specified Job ID.
 
         :param job_id: Job ID to get.
-        :type job_id: str
         :return: the list of AutoscalingEvents. See:
             https://cloud.google.com/dataflow/docs/reference/rest/v1b3/ListJobMessagesResponse#autoscalingevent
         :rtype: List[dict]
@@ -356,10 +349,13 @@ class _DataflowJobsController(LoggingMixin):
             .jobs()
             .list(projectId=self._project_number, location=self._job_location)
         )
-        jobs: List[dict] = []
+        all_jobs: List[dict] = []
         while request is not None:
             response = request.execute(num_retries=self._num_retries)
-            jobs.extend(response["jobs"])
+            jobs = response.get("jobs")
+            if jobs is None:
+                break
+            all_jobs.extend(jobs)
 
             request = (
                 self._dataflow.projects()
@@ -367,7 +363,7 @@ class _DataflowJobsController(LoggingMixin):
                 .jobs()
                 .list_next(previous_request=request, previous_response=response)
             )
-        return jobs
+        return all_jobs
 
     def _fetch_jobs_by_prefix_name(self, prefix_name: str) -> List[dict]:
         jobs = self._fetch_all_jobs()
@@ -438,7 +434,6 @@ class _DataflowJobsController(LoggingMixin):
         Returns Dataflow jobs.
 
         :param refresh: Forces the latest data to be fetched.
-        :type refresh: bool
         :return: list of jobs
         :rtype: list
         """
@@ -498,10 +493,11 @@ class _DataflowJobsController(LoggingMixin):
                 )
             batch.execute()
             if self._cancel_timeout and isinstance(self._cancel_timeout, int):
-                timeout_error_message = "Canceling jobs failed due to timeout ({}s): {}".format(
-                    self._cancel_timeout, ", ".join(job_ids)
+                timeout_error_message = (
+                    f"Canceling jobs failed due to timeout ({self._cancel_timeout}s): {', '.join(job_ids)}"
                 )
-                with timeout(seconds=self._cancel_timeout, error_message=timeout_error_message):
+                tm = timeout(seconds=self._cancel_timeout, error_message=timeout_error_message)
+                with tm:
                     self._wait_for_states({DataflowJobStatus.JOB_STATE_CANCELLED})
         else:
             self.log.info("No jobs to cancel")
@@ -561,23 +557,15 @@ class DataflowHook(GoogleBaseHook):
         Starts Dataflow java job.
 
         :param job_name: The name of the job.
-        :type job_name: str
         :param variables: Variables passed to the job.
-        :type variables: dict
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
         :param jar: Name of the jar for the job
-        :type job_class: str
         :param job_class: Name of the java class for the job.
-        :type job_class: str
         :param append_job_name: True if unique suffix has to be appended to job name.
-        :type append_job_name: bool
         :param multiple_jobs: True if to check for multiple job in dataflow
-        :type multiple_jobs: bool
         :param on_new_job_id_callback: Callback called when the job ID is known.
-        :type on_new_job_id_callback: callable
         :param location: Job location.
-        :type location: str
         """
         warnings.warn(
             """"This method is deprecated.
@@ -631,7 +619,6 @@ class DataflowHook(GoogleBaseHook):
         Starts Dataflow template job.
 
         :param job_name: The name of the job.
-        :type job_name: str
         :param variables: Map of job runtime environment options.
             It will update environment argument if passed.
 
@@ -640,29 +627,20 @@ class DataflowHook(GoogleBaseHook):
                 `https://cloud.google.com/dataflow/pipelines/specifying-exec-params
                 <https://cloud.google.com/dataflow/docs/reference/rest/v1b3/RuntimeEnvironment>`__
 
-        :type variables: dict
-        :param parameters: Parameters fot the template
-        :type parameters: dict
+        :param parameters: Parameters for the template
         :param dataflow_template: GCS path to the template.
-        :type dataflow_template: str
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
         :param append_job_name: True if unique suffix has to be appended to job name.
-        :type append_job_name: bool
         :param on_new_job_id_callback: (Deprecated) Callback called when the Job is known.
-        :type on_new_job_id_callback: callable
         :param on_new_job_callback: Callback called when the Job is known.
-        :type on_new_job_callback: callable
         :param location: Job location.
-        :type location: str
-        :type environment: Optional, Map of job runtime environment options.
 
             .. seealso::
                 For more information on possible configurations, look at the API documentation
                 `https://cloud.google.com/dataflow/pipelines/specifying-exec-params
                 <https://cloud.google.com/dataflow/docs/reference/rest/v1b3/RuntimeEnvironment>`__
 
-        :type environment: Optional[dict]
         """
         name = self.build_dataflow_job_name(job_name, append_job_name)
 
@@ -759,10 +737,8 @@ class DataflowHook(GoogleBaseHook):
         :param body: The request body. See:
             https://cloud.google.com/dataflow/docs/reference/rest/v1b3/projects.locations.flexTemplates/launch#request-body
         :param location: The location of the Dataflow job (for example europe-west1)
-        :type location: str
         :param project_id: The ID of the GCP project that owns the job.
             If set to ``None`` or missing, the default project_id from the GCP connection is used.
-        :type project_id: Optional[str]
         :param on_new_job_id_callback: (Deprecated) A callback that is called when a Job ID is detected.
         :param on_new_job_callback: A callback that is called when a Job is detected.
         :return: the Job
@@ -823,16 +799,11 @@ class DataflowHook(GoogleBaseHook):
         Starts Dataflow job.
 
         :param job_name: The name of the job.
-        :type job_name: str
         :param variables: Variables passed to the job.
-        :type variables: Dict
         :param dataflow: Name of the Dataflow process.
-        :type dataflow: str
         :param py_options: Additional options.
-        :type py_options: List[str]
         :param project_id: The ID of the GCP project that owns the job.
             If set to ``None`` or missing, the default project_id from the GCP connection is used.
-        :type project_id: Optional[str]
         :param py_interpreter: Python version of the beam pipeline.
             If None, this defaults to the python3.
             To track python versions supported by beam and related
@@ -843,20 +814,15 @@ class DataflowHook(GoogleBaseHook):
 
             You could also install the apache-beam package if it is not installed on your system or you want
             to use a different version.
-        :type py_requirements: List[str]
         :param py_system_site_packages: Whether to include system_site_packages in your virtualenv.
             See virtualenv documentation for more information.
 
             This option is only relevant if the ``py_requirements`` parameter is not None.
-        :type py_interpreter: str
         :param append_job_name: True if unique suffix has to be appended to job name.
-        :type append_job_name: bool
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
         :param on_new_job_id_callback: Callback called when the job ID is known.
-        :type on_new_job_id_callback: callable
         :param location: Job location.
-        :type location: str
         """
         warnings.warn(
             """This method is deprecated.
@@ -896,9 +862,8 @@ class DataflowHook(GoogleBaseHook):
 
         if not re.match(r"^[a-z]([-a-z0-9]*[a-z0-9])?$", base_job_name):
             raise ValueError(
-                "Invalid job_name ({}); the name must consist of"
-                "only the characters [-a-z0-9], starting with a "
-                "letter and ending with a letter or number ".format(base_job_name)
+                f"Invalid job_name ({base_job_name}); the name must consist of only the characters "
+                f"[-a-z0-9], starting with a letter and ending with a letter or number "
             )
 
         if append_job_name:
@@ -922,12 +887,9 @@ class DataflowHook(GoogleBaseHook):
         Helper method to check if jos is still running in dataflow
 
         :param name: The name of the job.
-        :type name: str
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param location: Job location.
-        :type location: str
         :return: True if job is running.
         :rtype: bool
         """
@@ -964,14 +926,10 @@ class DataflowHook(GoogleBaseHook):
         Parameter ``name`` and ``job_id`` are mutually exclusive.
 
         :param job_name: Name prefix specifying which jobs are to be canceled.
-        :type job_name: str
         :param job_id: Job ID specifying which jobs are to be canceled.
-        :type job_id: str
         :param location: Job location.
-        :type location: str
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id:
         """
         jobs_controller = _DataflowJobsController(
             dataflow=self.get_conn(),
@@ -1001,40 +959,49 @@ class DataflowHook(GoogleBaseHook):
         Starts Dataflow SQL query.
 
         :param job_name: The unique name to assign to the Cloud Dataflow job.
-        :type job_name: str
         :param query: The SQL query to execute.
-        :type query: str
         :param options: Job parameters to be executed.
             For more information, look at:
             `https://cloud.google.com/sdk/gcloud/reference/beta/dataflow/sql/query
             <gcloud beta dataflow sql query>`__
             command reference
         :param location: The location of the Dataflow job (for example europe-west1)
-        :type location: str
         :param project_id: The ID of the GCP project that owns the job.
             If set to ``None`` or missing, the default project_id from the GCP connection is used.
-        :type project_id: Optional[str]
         :param on_new_job_id_callback: (Deprecated) Callback called when the job ID is known.
-        :type on_new_job_id_callback: callable
         :param on_new_job_callback: Callback called when the job is known.
-        :type on_new_job_callback: callable
         :return: the new job object
         """
+        gcp_options = [
+            f"--project={project_id}",
+            "--format=value(job.id)",
+            f"--job-name={job_name}",
+            f"--region={location}",
+        ]
+
+        if self.impersonation_chain:
+            if isinstance(self.impersonation_chain, str):
+                impersonation_account = self.impersonation_chain
+            elif len(self.impersonation_chain) == 1:
+                impersonation_account = self.impersonation_chain[0]
+            else:
+                raise AirflowException(
+                    "Chained list of accounts is not supported, please specify only one service account"
+                )
+            gcp_options.append(f"--impersonate-service-account={impersonation_account}")
+
         cmd = [
             "gcloud",
             "dataflow",
             "sql",
             "query",
             query,
-            f"--project={project_id}",
-            "--format=value(job.id)",
-            f"--job-name={job_name}",
-            f"--region={location}",
+            *gcp_options,
             *(beam_options_to_args(options)),
         ]
         self.log.info("Executing command: %s", " ".join(shlex.quote(c) for c in cmd))
         with self.provide_authorized_gcloud():
-            proc = subprocess.run(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            proc = subprocess.run(cmd, capture_output=True)
         self.log.info("Output: %s", proc.stdout.decode())
         self.log.warning("Stderr: %s", proc.stderr.decode())
         self.log.info("Exit code %d", proc.returncode)
@@ -1062,7 +1029,7 @@ class DataflowHook(GoogleBaseHook):
                 DeprecationWarning,
                 stacklevel=3,
             )
-            on_new_job_id_callback(job.get("id"))
+            on_new_job_id_callback(cast(str, job.get("id")))
 
         if on_new_job_callback:
             on_new_job_callback(job)
@@ -1081,10 +1048,8 @@ class DataflowHook(GoogleBaseHook):
         Gets the job with the specified Job ID.
 
         :param job_id: Job ID to get.
-        :type job_id: str
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id:
         :param location: The location of the Dataflow job (for example europe-west1). See:
             https://cloud.google.com/dataflow/docs/concepts/regional-endpoints
         :return: the Job
@@ -1108,10 +1073,8 @@ class DataflowHook(GoogleBaseHook):
         Gets the job metrics with the specified Job ID.
 
         :param job_id: Job ID to get.
-        :type job_id: str
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id:
         :param location: The location of the Dataflow job (for example europe-west1). See:
             https://cloud.google.com/dataflow/docs/concepts/regional-endpoints
         :return: the JobMetrics. See:
@@ -1136,12 +1099,9 @@ class DataflowHook(GoogleBaseHook):
         Gets the job messages with the specified Job ID.
 
         :param job_id: Job ID to get.
-        :type job_id: str
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id:
         :param location: Job location.
-        :type location: str
         :return: the list of JobMessages. See:
             https://cloud.google.com/dataflow/docs/reference/rest/v1b3/ListJobMessagesResponse#JobMessage
         :rtype: List[dict]
@@ -1164,12 +1124,9 @@ class DataflowHook(GoogleBaseHook):
         Gets the job autoscaling events with the specified Job ID.
 
         :param job_id: Job ID to get.
-        :type job_id: str
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id:
         :param location: Job location.
-        :type location: str
         :return: the list of AutoscalingEvents. See:
             https://cloud.google.com/dataflow/docs/reference/rest/v1b3/ListJobMessagesResponse#autoscalingevent
         :rtype: List[dict]
@@ -1196,16 +1153,11 @@ class DataflowHook(GoogleBaseHook):
         :param job_name: The 'jobName' to use when executing the DataFlow job
             (templated). This ends up being set in the pipeline options, so any entry
             with key ``'jobName'`` in ``options`` will be overwritten.
-        :type job_name: str
         :param location: location the job is running
-        :type location: str
         :param project_id: Optional, the Google Cloud project ID in which to start a job.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id:
         :param job_id: a Dataflow job ID
-        :type job_id: str
         :param multiple_jobs: If pipeline creates multiple jobs then monitor all jobs
-        :type multiple_jobs: boolean
         """
         job_controller = _DataflowJobsController(
             dataflow=self.get_conn(),
