@@ -41,15 +41,10 @@ def _poll_with_exponential_delay(request, execute_num_retries, max_n, is_done_fu
     lower level errors like `ConnectionError`/`socket.timeout`/`ssl.SSLError`.
 
     :param request: request to be executed.
-    :type request: googleapiclient.http.HttpRequest
     :param execute_num_retries: num_retries for `request.execute` method.
-    :type execute_num_retries: int
     :param max_n: number of times to retry request in this method.
-    :type max_n: int
     :param is_done_func: callable to determine if operation is done.
-    :type is_done_func: callable
     :param is_error_func: callable to determine if operation is failed.
-    :type is_error_func: callable
     :return: response
     :rtype: httplib2.Response
     """
@@ -62,13 +57,13 @@ def _poll_with_exponential_delay(request, execute_num_retries, max_n, is_done_fu
                 log.info('Operation is done: %s', response)
                 return response
 
-            time.sleep((2 ** i) + (random.randint(0, 1000) / 1000))
+            time.sleep((2**i) + (random.randint(0, 1000) / 1000))
         except HttpError as e:
             if e.resp.status != 429:
                 log.info('Something went wrong. Not retrying: %s', format(e))
                 raise
             else:
-                time.sleep((2 ** i) + (random.randint(0, 1000) / 1000))
+                time.sleep((2**i) + (random.randint(0, 1000) / 1000))
 
     raise ValueError(f'Connection could not be established after {max_n} retries.')
 
@@ -98,7 +93,6 @@ class MLEngineHook(GoogleBaseHook):
         :param project_id: The Google Cloud project id within which MLEngine
             job will be launched. If set to None or missing, the default project_id from the Google Cloud
             connection is used.
-        :type project_id: str
         :param job: MLEngine Job object that should be provided to the MLEngine
             API, such as: ::
 
@@ -110,7 +104,6 @@ class MLEngineHook(GoogleBaseHook):
                   }
                 }
 
-        :type job: dict
         :param use_existing_job_fn: In case that a MLEngine job with the same
             job_id already exist, this method (if provided) will decide whether
             we should use this existing job, continue waiting for it to finish
@@ -118,7 +111,6 @@ class MLEngineHook(GoogleBaseHook):
             object, and returns a boolean value indicating whether it is OK to
             reuse the existing job. If 'use_existing_job_fn' is not provided,
             we by default reuse the existing MLEngine job.
-        :type use_existing_job_fn: function
         :return: The MLEngine job object if the job successfully reach a
             terminal state (which might be FAILED or CANCELLED state).
         :rtype: dict
@@ -164,9 +156,7 @@ class MLEngineHook(GoogleBaseHook):
         :param project_id: The Google Cloud project id within which MLEngine
             job will be cancelled. If set to None or missing, the default project_id from the Google Cloud
             connection is used.
-        :type project_id: str
         :param job_id: A unique id for the want-to-be cancelled Google MLEngine training job.
-        :type job_id: str
 
         :return: Empty dict if cancelled successfully
         :rtype: dict
@@ -195,9 +185,7 @@ class MLEngineHook(GoogleBaseHook):
 
         :param project_id: The project in which the Job is located. If set to None or missing, the default
             project_id from the Google Cloud connection is used. (templated)
-        :type project_id: str
         :param job_id: A unique id for the Google MLEngine job. (templated)
-        :type job_id: str
         :return: MLEngine job object if succeed.
         :rtype: dict
         :raises: googleapiclient.errors.HttpError
@@ -225,11 +213,8 @@ class MLEngineHook(GoogleBaseHook):
 
         :param project_id: The project in which the Job is located. If set to None or missing, the default
             project_id from the Google Cloud connection is used. (templated)
-        :type project_id: str
         :param job_id: A unique id for the Google MLEngine job. (templated)
-        :type job_id: str
         :param interval: Time expressed in seconds after which the job status is checked again. (templated)
-        :type interval: int
         :raises: googleapiclient.errors.HttpError
         """
         self.log.info("Waiting for job. job_id=%s", job_id)
@@ -253,14 +238,11 @@ class MLEngineHook(GoogleBaseHook):
         Creates the Version on Google Cloud ML Engine.
 
         :param version_spec: A dictionary containing the information about the version. (templated)
-        :type version_spec: dict
         :param model_name: The name of the Google Cloud ML Engine model that the version belongs to.
             (templated)
-        :type model_name: str
         :param project_id: The Google Cloud project name to which MLEngine model belongs.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
             (templated)
-        :type project_id: str
         :return: If the version was created successfully, returns the operation.
             Otherwise raises an error .
         :rtype: dict
@@ -294,12 +276,9 @@ class MLEngineHook(GoogleBaseHook):
 
         :param model_name: The name of the Google Cloud ML Engine model that the version belongs to.
             (templated)
-        :type model_name: str
         :param version_name: A name to use for the version being operated upon. (templated)
-        :type version_name: str
         :param project_id: The Google Cloud project name to which MLEngine model belongs. If set to None
             or missing, the default project_id from the Google Cloud connection is used. (templated)
-        :type project_id: str
         :return: If successful, return an instance of Version.
             Otherwise raises an error.
         :rtype: dict
@@ -329,10 +308,8 @@ class MLEngineHook(GoogleBaseHook):
 
         :param model_name: The name of the Google Cloud ML Engine model that the version
             belongs to. (templated)
-        :type model_name: str
         :param project_id: The Google Cloud project name to which MLEngine model belongs. If set to None or
             missing, the default project_id from the Google Cloud connection is used. (templated)
-        :type project_id: str
         :return: return an list of instance of Version.
         :rtype: List[Dict]
         :raises: googleapiclient.errors.HttpError
@@ -368,10 +345,8 @@ class MLEngineHook(GoogleBaseHook):
 
         :param model_name: The name of the Google Cloud ML Engine model that the version
             belongs to. (templated)
-        :type model_name: str
         :param project_id: The Google Cloud project name to which MLEngine
             model belongs.
-        :type project_id: str
         :return: If the version was deleted successfully, returns the operation.
             Otherwise raises an error.
         :rtype: Dict
@@ -400,10 +375,8 @@ class MLEngineHook(GoogleBaseHook):
         Create a Model. Blocks until finished.
 
         :param model: A dictionary containing the information about the model.
-        :type model: dict
         :param project_id: The Google Cloud project name to which MLEngine model belongs. If set to None or
             missing, the default project_id from the Google Cloud connection is used. (templated)
-        :type project_id: str
         :return: If the version was created successfully, returns the instance of Model.
             Otherwise raises an error.
         :rtype: Dict
@@ -452,10 +425,8 @@ class MLEngineHook(GoogleBaseHook):
         Gets a Model. Blocks until finished.
 
         :param model_name: The name of the model.
-        :type model_name: str
         :param project_id: The Google Cloud project name to which MLEngine model belongs. If set to None
             or missing, the default project_id from the Google Cloud connection is used. (templated)
-        :type project_id: str
         :return: If the model exists, returns the instance of Model.
             Otherwise return None.
         :rtype: Dict
@@ -485,14 +456,11 @@ class MLEngineHook(GoogleBaseHook):
         Delete a Model. Blocks until finished.
 
         :param model_name: The name of the model.
-        :type model_name: str
         :param delete_contents: Whether to force the deletion even if the models is not empty.
             Will delete all version (if any) in the dataset if set to True.
             The default value is False.
-        :type delete_contents: bool
         :param project_id: The Google Cloud project name to which MLEngine model belongs. If set to None
             or missing, the default project_id from the Google Cloud connection is used. (templated)
-        :type project_id: str
         :raises: googleapiclient.errors.HttpError
         """
         hook = self.get_conn()
