@@ -78,7 +78,7 @@ class CloudTasksHook(GoogleBaseHook):
         :rtype: google.cloud.tasks_v2.CloudTasksClient
         """
         if self._client is None:
-            self._client = CloudTasksClient(credentials=self._get_credentials(), client_info=CLIENT_INFO)
+            self._client = CloudTasksClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
         return self._client
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -298,7 +298,7 @@ class CloudTasksHook(GoogleBaseHook):
         retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> List[Queue]:
+    ) -> Queue:
         """
         Purges a queue by deleting all of its tasks from Cloud Tasks.
 
@@ -333,7 +333,7 @@ class CloudTasksHook(GoogleBaseHook):
         retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> List[Queue]:
+    ) -> Queue:
         """
         Pauses a queue in Cloud Tasks.
 
@@ -368,7 +368,7 @@ class CloudTasksHook(GoogleBaseHook):
         retry: Union[Retry, _MethodDefault] = DEFAULT,
         timeout: Optional[float] = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> List[Queue]:
+    ) -> Queue:
         """
         Resumes a queue in Cloud Tasks.
 
