@@ -808,7 +808,7 @@ class AutoMLDeployModelOperator(BaseOperator):
     """
     Deploys a model. If a model is already deployed, deploying it with the same parameters
     has no effect. Deploying with different parameters (as e.g. changing node_number) will
-    reset the deployment state without pausing the model_id’s availability.
+    reset the deployment state without pausing the model_id's availability.
 
     Only applicable for Text Classification, Image Object Detection and Tables; all other
     domains manage deployment automatically.
