@@ -20,12 +20,10 @@
 
 import json
 import re
-import warnings
 from copy import deepcopy
 from typing import TYPE_CHECKING, Any, Dict, Optional, Sequence, Tuple, Union
 from urllib.parse import unquote, urlparse
 
-import yaml
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
 from google.cloud.devtools.cloudbuild_v1.types import Build, BuildTrigger, RepoSource
@@ -33,6 +31,13 @@ from google.cloud.devtools.cloudbuild_v1.types import Build, BuildTrigger, RepoS
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.cloud_build import CloudBuildHook
+from airflow.providers.google.cloud.links.cloud_build import (
+    CloudBuildLink,
+    CloudBuildListLink,
+    CloudBuildTriggerDetailsLink,
+    CloudBuildTriggersListLink,
+)
+from airflow.utils import yaml
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -71,6 +76,7 @@ class CloudBuildCancelBuildOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = ("project_id", "id_", "gcp_conn_id")
+    operator_extra_links = (CloudBuildLink(),)
 
     def __init__(
         self,
@@ -102,6 +108,16 @@ class CloudBuildCancelBuildOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+
+        self.xcom_push(context, key="id", value=result.id)
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            CloudBuildLink.persist(
+                context=context,
+                task_instance=self,
+                project_id=project_id,
+                build_id=result.id,
+            )
         return Build.to_dict(result)
 
 
@@ -113,11 +129,8 @@ class CloudBuildCreateBuildOperator(BaseOperator):
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:CloudBuildCreateBuildOperator`
 
-    :param build: Optional, the build resource to create. If a dict is provided, it must be of
+    :param build: The build resource to create. If a dict is provided, it must be of
         the same form as the protobuf message `google.cloud.devtools.cloudbuild_v1.types.Build`.
-        Only either build or body should be passed.
-    :param body: (Deprecated) The build resource to create.
-        This parameter has been deprecated. You should pass the build parameter instead.
     :param project_id: Optional, Google Cloud Project project_id where the function belongs.
         If set to None or missing, the default project_id from the GCP connection is used.
     :param wait: Optional, wait for operation to finish.
@@ -139,13 +152,13 @@ class CloudBuildCreateBuildOperator(BaseOperator):
     :rtype: dict
     """
 
-    template_fields: Sequence[str] = ("project_id", "build", "body", "gcp_conn_id", "impersonation_chain")
+    template_fields: Sequence[str] = ("project_id", "build", "gcp_conn_id", "impersonation_chain")
+    operator_extra_links = (CloudBuildLink(),)
 
     def __init__(
         self,
         *,
-        build: Optional[Union[Dict, Build]] = None,
-        body: Optional[Dict] = None,
+        build: Union[Dict, Build],
         project_id: Optional[str] = None,
         wait: bool = True,
         retry: Union[Retry, _MethodDefault] = DEFAULT,
@@ -163,25 +176,9 @@ class CloudBuildCreateBuildOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
-        self.body = body
-
-        if body and build:
-            raise AirflowException("You should not pass both build or body parameters. Both are set.")
-        if body is not None:
-            warnings.warn(
-                "The body parameter has been deprecated. You should pass body using the build parameter.",
-                DeprecationWarning,
-                stacklevel=4,
-            )
-            actual_build = body
-        else:
-            if build is None:
-                raise AirflowException("You should pass one of the build or body parameters. Both are None")
-            actual_build = build
-
-        self.build = actual_build
+        self.build = build
         # Not template fields to keep original value
-        self.build_raw = actual_build
+        self.build_raw = build
 
     def prepare_template(self) -> None:
         # if no file is specified, skip
@@ -206,6 +203,16 @@ class CloudBuildCreateBuildOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+
+        self.xcom_push(context, key="id", value=result.id)
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            CloudBuildLink.persist(
+                context=context,
+                task_instance=self,
+                project_id=project_id,
+                build_id=result.id,
+            )
         return Build.to_dict(result)
 
 
@@ -240,6 +247,10 @@ class CloudBuildCreateBuildTriggerOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = ("project_id", "trigger", "gcp_conn_id")
+    operator_extra_links = (
+        CloudBuildTriggersListLink(),
+        CloudBuildTriggerDetailsLink(),
+    )
 
     def __init__(
         self,
@@ -271,6 +282,20 @@ class CloudBuildCreateBuildTriggerOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        self.xcom_push(context, key="id", value=result.id)
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            CloudBuildTriggerDetailsLink.persist(
+                context=context,
+                task_instance=self,
+                project_id=project_id,
+                trigger_id=result.id,
+            )
+            CloudBuildTriggersListLink.persist(
+                context=context,
+                task_instance=self,
+                project_id=project_id,
+            )
         return BuildTrigger.to_dict(result)
 
 
@@ -302,6 +327,7 @@ class CloudBuildDeleteBuildTriggerOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = ("project_id", "trigger_id", "gcp_conn_id")
+    operator_extra_links = (CloudBuildTriggersListLink(),)
 
     def __init__(
         self,
@@ -333,6 +359,13 @@ class CloudBuildDeleteBuildTriggerOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            CloudBuildTriggersListLink.persist(
+                context=context,
+                task_instance=self,
+                project_id=project_id,
+            )
 
 
 class CloudBuildGetBuildOperator(BaseOperator):
@@ -365,6 +398,7 @@ class CloudBuildGetBuildOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = ("project_id", "id_", "gcp_conn_id")
+    operator_extra_links = (CloudBuildLink(),)
 
     def __init__(
         self,
@@ -396,6 +430,14 @@ class CloudBuildGetBuildOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            CloudBuildLink.persist(
+                context=context,
+                task_instance=self,
+                project_id=project_id,
+                build_id=result.id,
+            )
         return Build.to_dict(result)
 
 
@@ -429,6 +471,7 @@ class CloudBuildGetBuildTriggerOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = ("project_id", "trigger_id", "gcp_conn_id")
+    operator_extra_links = (CloudBuildTriggerDetailsLink(),)
 
     def __init__(
         self,
@@ -460,6 +503,14 @@ class CloudBuildGetBuildTriggerOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            CloudBuildTriggerDetailsLink.persist(
+                context=context,
+                task_instance=self,
+                project_id=project_id,
+                trigger_id=result.id,
+            )
         return BuildTrigger.to_dict(result)
 
 
@@ -495,6 +546,7 @@ class CloudBuildListBuildTriggersOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = ("location", "project_id", "gcp_conn_id")
+    operator_extra_links = (CloudBuildTriggersListLink(),)
 
     def __init__(
         self,
@@ -532,6 +584,13 @@ class CloudBuildListBuildTriggersOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            CloudBuildTriggersListLink.persist(
+                context=context,
+                task_instance=self,
+                project_id=project_id,
+            )
         return [BuildTrigger.to_dict(result) for result in results]
 
 
@@ -567,6 +626,7 @@ class CloudBuildListBuildsOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = ("location", "project_id", "gcp_conn_id")
+    operator_extra_links = (CloudBuildListLink(),)
 
     def __init__(
         self,
@@ -604,6 +664,9 @@ class CloudBuildListBuildsOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            CloudBuildListLink.persist(context=context, task_instance=self, project_id=project_id)
         return [Build.to_dict(result) for result in results]
 
 
@@ -639,6 +702,7 @@ class CloudBuildRetryBuildOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = ("project_id", "id_", "gcp_conn_id")
+    operator_extra_links = (CloudBuildLink(),)
 
     def __init__(
         self,
@@ -673,6 +737,16 @@ class CloudBuildRetryBuildOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+
+        self.xcom_push(context, key="id", value=result.id)
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            CloudBuildLink.persist(
+                context=context,
+                task_instance=self,
+                project_id=project_id,
+                build_id=result.id,
+            )
         return Build.to_dict(result)
 
 
@@ -709,6 +783,7 @@ class CloudBuildRunBuildTriggerOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = ("project_id", "trigger_id", "source", "gcp_conn_id")
+    operator_extra_links = (CloudBuildLink(),)
 
     def __init__(
         self,
@@ -746,6 +821,15 @@ class CloudBuildRunBuildTriggerOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        self.xcom_push(context, key="id", value=result.id)
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            CloudBuildLink.persist(
+                context=context,
+                task_instance=self,
+                project_id=project_id,
+                build_id=result.id,
+            )
         return Build.to_dict(result)
 
 
@@ -781,6 +865,7 @@ class CloudBuildUpdateBuildTriggerOperator(BaseOperator):
     """
 
     template_fields: Sequence[str] = ("project_id", "trigger_id", "trigger", "gcp_conn_id")
+    operator_extra_links = (CloudBuildTriggerDetailsLink(),)
 
     def __init__(
         self,
@@ -815,6 +900,15 @@ class CloudBuildUpdateBuildTriggerOperator(BaseOperator):
             timeout=self.timeout,
             metadata=self.metadata,
         )
+        self.xcom_push(context, key="id", value=result.id)
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            CloudBuildTriggerDetailsLink.persist(
+                context=context,
+                task_instance=self,
+                project_id=project_id,
+                trigger_id=result.id,
+            )
         return BuildTrigger.to_dict(result)
 
 
