@@ -21,7 +21,6 @@ data from Cassandra to Google Cloud Storage in JSON format.
 """
 
 import json
-import warnings
 from base64 import b64encode
 from datetime import datetime
 from decimal import Decimal
@@ -66,8 +65,6 @@ class CassandraToGCSOperator(BaseOperator):
     :param cassandra_conn_id: Reference to a specific Cassandra hook.
     :param gzip: Option to compress file for upload
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :param google_cloud_storage_conn_id: (Deprecated) The connection ID used to connect to Google Cloud.
-        This parameter has been deprecated. You should pass the gcp_conn_id parameter instead.
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
@@ -82,6 +79,8 @@ class CassandraToGCSOperator(BaseOperator):
     :param query_timeout: (Optional) The amount of time, in seconds, used to execute the Cassandra query.
         If not set, the timeout value will be set in Session.execute() by Cassandra driver.
         If set to None, there is no timeout.
+    :param encode_uuid: (Optional) Option to encode UUID or not when upload from Cassandra to GCS.
+        Default is to encode UUID.
     """
 
     template_fields: Sequence[str] = (
@@ -105,23 +104,14 @@ class CassandraToGCSOperator(BaseOperator):
         gzip: bool = False,
         cassandra_conn_id: str = 'cassandra_default',
         gcp_conn_id: str = 'google_cloud_default',
-        google_cloud_storage_conn_id: Optional[str] = None,
         delegate_to: Optional[str] = None,
         impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
         query_timeout: Union[float, None, NotSetType] = NOT_SET,
+        encode_uuid: bool = True,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
 
-        if google_cloud_storage_conn_id:
-            warnings.warn(
-                "The google_cloud_storage_conn_id parameter has been deprecated. You should pass "
-                "the gcp_conn_id parameter.",
-                DeprecationWarning,
-                stacklevel=3,
-            )
-            gcp_conn_id = google_cloud_storage_conn_id
-
         self.cql = cql
         self.bucket = bucket
         self.filename = filename
@@ -133,6 +123,7 @@ class CassandraToGCSOperator(BaseOperator):
         self.gzip = gzip
         self.impersonation_chain = impersonation_chain
         self.query_timeout = query_timeout
+        self.encode_uuid = encode_uuid
 
     # Default Cassandra to BigQuery type mapping
     CQL_TYPE_MAP = {
@@ -269,13 +260,11 @@ class CassandraToGCSOperator(BaseOperator):
             gzip=self.gzip,
         )
 
-    @classmethod
-    def generate_data_dict(cls, names: Iterable[str], values: Any) -> Dict[str, Any]:
+    def generate_data_dict(self, names: Iterable[str], values: Any) -> Dict[str, Any]:
         """Generates data structure that will be stored as file in GCS."""
-        return {n: cls.convert_value(v) for n, v in zip(names, values)}
+        return {n: self.convert_value(v) for n, v in zip(names, values)}
 
-    @classmethod
-    def convert_value(cls, value: Optional[Any]) -> Optional[Any]:
+    def convert_value(self, value: Optional[Any]) -> Optional[Any]:
         """Convert value to BQ type."""
         if not value:
             return value
@@ -284,7 +273,10 @@ class CassandraToGCSOperator(BaseOperator):
         elif isinstance(value, bytes):
             return b64encode(value).decode('ascii')
         elif isinstance(value, UUID):
-            return b64encode(value.bytes).decode('ascii')
+            if self.encode_uuid:
+                return b64encode(value.bytes).decode('ascii')
+            else:
+                return str(value)
         elif isinstance(value, (datetime, Date)):
             return str(value)
         elif isinstance(value, Decimal):
@@ -292,51 +284,47 @@ class CassandraToGCSOperator(BaseOperator):
         elif isinstance(value, Time):
             return str(value).split('.')[0]
         elif isinstance(value, (list, SortedSet)):
-            return cls.convert_array_types(value)
+            return self.convert_array_types(value)
         elif hasattr(value, '_fields'):
-            return cls.convert_user_type(value)
+            return self.convert_user_type(value)
         elif isinstance(value, tuple):
-            return cls.convert_tuple_type(value)
+            return self.convert_tuple_type(value)
         elif isinstance(value, OrderedMapSerializedKey):
-            return cls.convert_map_type(value)
+            return self.convert_map_type(value)
         else:
             raise AirflowException('Unexpected value: ' + str(value))
 
-    @classmethod
-    def convert_array_types(cls, value: Union[List[Any], SortedSet]) -> List[Any]:
+    def convert_array_types(self, value: Union[List[Any], SortedSet]) -> List[Any]:
         """Maps convert_value over array."""
-        return [cls.convert_value(nested_value) for nested_value in value]
+        return [self.convert_value(nested_value) for nested_value in value]
 
-    @classmethod
-    def convert_user_type(cls, value: Any) -> Dict[str, Any]:
+    def convert_user_type(self, value: Any) -> Dict[str, Any]:
         """
         Converts a user type to RECORD that contains n fields, where n is the
         number of attributes. Each element in the user type class will be converted to its
         corresponding data type in BQ.
         """
         names = value._fields
-        values = [cls.convert_value(getattr(value, name)) for name in names]
-        return cls.generate_data_dict(names, values)
+        values = [self.convert_value(getattr(value, name)) for name in names]
+        return self.generate_data_dict(names, values)
 
-    @classmethod
-    def convert_tuple_type(cls, values: Tuple[Any]) -> Dict[str, Any]:
+    def convert_tuple_type(self, values: Tuple[Any]) -> Dict[str, Any]:
         """
         Converts a tuple to RECORD that contains n fields, each will be converted
         to its corresponding data type in bq and will be named 'field_<index>', where
         index is determined by the order of the tuple elements defined in cassandra.
         """
         names = ['field_' + str(i) for i in range(len(values))]
-        return cls.generate_data_dict(names, values)
+        return self.generate_data_dict(names, values)
 
-    @classmethod
-    def convert_map_type(cls, value: OrderedMapSerializedKey) -> List[Dict[str, Any]]:
+    def convert_map_type(self, value: OrderedMapSerializedKey) -> List[Dict[str, Any]]:
         """
         Converts a map to a repeated RECORD that contains two fields: 'key' and 'value',
         each will be converted to its corresponding data type in BQ.
         """
         converted_map = []
         for k, v in zip(value.keys(), value.values()):
-            converted_map.append({'key': cls.convert_value(k), 'value': cls.convert_value(v)})
+            converted_map.append({'key': self.convert_value(k), 'value': self.convert_value(v)})
         return converted_map
 
     @classmethod
